import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "CombatAlert.Options";
import "CombatAlert.Utils";

defaultSettings = {
    visualalert = true,
    entercombatalert = true,
    leavecombatalert = true
}

CA = Turbine.UI.Window();
CA.WinWidth, CA.WinHeight = Turbine.UI.Display:GetSize();
CA:SetPosition(0, 0);
CA:SetSize(CA.WinWidth, CA.WinHeight);
CA:SetBlendMode(Turbine.UI.BlendMode.Undefined);
CA:SetBackColor(Turbine.UI.Color(0, 0, 0, 0));
CA:SetOpacity(1);
CA.sleepEnd = 0;
CA.settings = Turbine.PluginData.Load(Turbine.DataScope.Account,
    "CombatAlert") or defaultSettings;

CA.optPanel = CreateOptionsPanel(CA);
plugin.GetOptionsPanel = function()
    return CA.optPanel
end

CA.AlertImgWin = Turbine.UI.Window();
CA.AlertImgWin:SetParent(CA);
CA.AlertImgWin:SetPosition(0, 0);
CA.AlertImgWin:SetSize(CA.WinWidth, CA.WinHeight);
CA.AlertImgWin:SetBlendMode(Turbine.UI.BlendMode.Undefined);
CA.AlertImgWin:SetBackColor(Turbine.UI.Color(0, 0, 0, 0));
CA.AlertImgWin:SetOpacity(1);
CA.AlertImgWin:SetZOrder(-1);

CA.AlertDisplay = Turbine.UI.Control();
CA.AlertDisplay:SetParent(CA.AlertImgWin);
CA.AlertDisplay:SetPosition(0, 0);
CA.AlertDisplay:SetMouseVisible(true);
CA.AlertDisplay:SetZOrder(0);
CA.AlertDisplay:SetSize(1100, 500);
CA.AlertDisplay:SetStretchMode(1);
CA.AlertDisplay:SetSize(CA.WinWidth, CA.WinHeight);
CA.AlertDisplay:SetBackground(CA.settings.visualalert and
    "CombatAlert/Resources/AlertImage.tga" or "")

CA.label = Turbine.UI.Label();
CA.label:SetParent(CA);
CA.label:SetSize(300, 30);
CA.label:SetPosition((CA.WinWidth / 2) - 150, CA.WinHeight / 4);
CA.label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
CA.label:SetFont(Turbine.UI.Lotro.Font.TrajanProBold30);
CA.label:SetFontStyle(Turbine.UI.FontStyle.Outline);
CA.label:SetOutlineColor(Turbine.UI.Color(0, 0, 0));

CA.player = Turbine.Gameplay.LocalPlayer.GetInstance();
if not CA.player then
    Turbine.Shell.WriteLine("Error: player is nil");
    return
end

CA.CombatChanged = function(sender, args)
    local inCombat = CA.player:IsInCombat()
    local settings = CA.settings
    local alertDisplay = CA.AlertDisplay
    local label = CA.label

    if inCombat then
        if settings.visualalert then
            alertDisplay:SetOpacity(1)
        end
        label:SetForeColor(Turbine.UI.Color(0, 255, 0))
        label:SetText(settings.entercombatalert and
            "Entering Combat" or "")
        CA.sleepEnd = Turbine.Engine.GetGameTime() + 3
    else
        label:SetForeColor(Turbine.UI.Color(0, 0, 210))
        label:SetText(settings.leavecombatalert and
            "Leaving Combat" or "")
        alertDisplay:SetOpacity(0)
        CA.sleepEnd = Turbine.Engine.GetGameTime() + 1.5
    end

    CA.AlertImgWin:SetVisible(true)
    CA:SetVisible(true)
    CA:SetWantsUpdates(true)  -- Enable updates when combat status changes
end

AddCallback(CA.player, "InCombatChanged", CA.CombatChanged)

CA.Update = function()
    if Turbine.Engine.GetGameTime() > CA.sleepEnd then
        CA.AlertImgWin:SetVisible(false)
        CA:SetVisible(false)
        CA:SetWantsUpdates(false)  -- Disable updates when no longer needed
    end
end

CA.saveSettings = function()
    local optPanel = CA.optPanel
    CA.settings.visualalert = optPanel.visualCB:IsChecked()
    CA.settings.entercombatalert = optPanel.enterCB:IsChecked()
    CA.settings.leavecombatalert = optPanel.leaveCB:IsChecked()
    Turbine.PluginData.Save(Turbine.DataScope.Account,
        "CombatAlert", CA.settings)
end

CA.Destructor = function()
    RemoveCallback(CA.player, "InCombatChanged", CA.CombatChanged)
end
